@@ -11,10 +11,8 @@ import datetime
 import logging
 import re
 import sys
-import time
 from decimal import Decimal
 from io import BytesIO
-from itertools import islice
 from ssl import CERT_NONE, CERT_OPTIONAL, CERT_REQUIRED
 
 from thrift.protocol import TBinaryProtocol, TMultiplexedProtocol
@@ -152,10 +150,9 @@ class Connection(object):
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         """Call close"""
-        self.close(self)
+        self.close()
 
-    def close(self, query_id):
-        self._client.clear(query_id)
+    def close(self):
         self._transport.close()
 
     def check_connection(self):
@@ -274,7 +271,7 @@ class Cursor(DBAPICursor):
 
     def close(self):
         """Close the operation handle"""
-        self.connection.close(self._query_id)
+        self.connection.close()
         self._arraysize = None
         self.connection = None
         self._data = None
@@ -283,7 +280,6 @@ class Cursor(DBAPICursor):
         self._query_id = None
         self._batch = None
         self._rowcount = None
-        pass
 
     def get_tables(self):
         schema = self.connection.database
@@ -334,7 +330,7 @@ class Cursor(DBAPICursor):
         self._data = list()
         for i in range(batch_size):
             rows = self.fetch_batch()
-            if row is None:
+            if rows is None:
                 return
             self._data = self._data + rows
 
@@ -426,60 +422,37 @@ class Error(Exception):
     pass
 
 
-if __name__ == '__main__':
-    connection = connect(host="localhost",
-                         port=9000,
-                         scheme="e6xdb",
-                         username="admin",
-                         database="tpcds_10gb",
-                         auth=None,
-                         configuration=None,
-                         kerberos_service_name=None,
-                         password="admin",
-                         check_hostname=None,
-                         ssl_cert=None,
-                         thrift_transport=None)
-    cursor = Cursor(connection)
-    cursor.execute("SELECT * from catalog_sales limit 100000;")
-    bdata = []
-    try:
-        for i in range(1000):
-            bdata += cursor.fetchmany()
-        print('total rows in the batch resultset ', len(bdata))
-        r_count = cursor.rowcount()
-        print('total row count', r_count)
-    except Exception as e:
-        print('Error Message ', e.__cause__)
-
-    while True:
-        try:
-            connection = connect(host="localhost",
-                                 port=9000,
-                                 scheme="e6xdb",
-                                 username="admin",
-                                 database="tpcds_10gb",
-                                 auth=None,
-                                 configuration=None,
-                                 kerberos_service_name=None,
-                                 password="admin",
-                                 check_hostname=None,
-                                 ssl_cert=None,
-                                 thrift_transport=None)
-            cursor = Cursor(connection)
-            isOpen = cursor.connection.check_connection
-            if not isOpen:
-                time.sleep(5)
-                continue
-            else:
-                break
-        except:
-            time.sleep(5)
-            continue
-
-    cursor.execute("SELECT * from catalog_sales limit 100;")
-    bdata = []
-    for i in range(1000):
-        bdata += cursor.fetchmany()
+# if __name__ == '__main__':
+#     e6x_connection = connect(host="e6data-cls6-rj7u4l-042347692bba1a38.elb.us-east-1.amazonaws.com",
+#                          port=9000,
+#                          scheme="e6xdb",
+#                          username="admin",
+#                          database="dev_hive_100gb",
+#                          auth=None,
+#                          configuration=None,
+#                          kerberos_service_name=None,
+#                          password="admin",
+#                          check_hostname=None,
+#                          ssl_cert=None,
+#                          thrift_transport=None)
+#     cursor = e6x_connection.cursor()
+#     query = 'SELECT * FROM date_dim limit 4;'
+#     cursor.execute(query)
+#     all_records = cursor.fetchall()
+#     print(all_records)
+#     # cursor.close()
+#     e6x_connection.close()
+#
+#     e6x_connection.reopen()
+#
+#     cursor = e6x_connection.cursor()
+#     query = 'SELECT * FROM date_dim limit 4;'
+#     cursor.execute(query)
+#     all_records = cursor.fetchall()
+#     print(all_records)
+#     # cursor.close()
+#
+#     e6x_connection.close()
 
 #
 # Type Objects and Constructors
